@@ -2,59 +2,60 @@
 ### Encoding: ISO8859-1
 
 ###################################################
-### code chunk number 1: preliminaries
+### code chunk number 1: options
 ###################################################
-options(prompt="R> ", continue="+  ", width=70, useFancyQuotes=FALSE)
-library("tscount")
+options(prompt="R> ", continue="+  ", width=76, useFancyQuotes=FALSE, digits=4)
 
 
 ###################################################
 ### code chunk number 2: campy1
 ###################################################
-par(mar=c(4,4,1,1), mgp=c(2.5,1,0))
+library("tscount")
+par(mar=c(3, 3, 0.5, 0.5), mgp=c(1.8, 0.6, 0))
 plot(campy, ylab="Number of cases", type="o")
 
 
 ###################################################
 ### code chunk number 3: campy2
 ###################################################
-interventions <- interv_covariate(n=length(campy), tau=c(84, 100),
-                  delta=c(1, 0))
-campyfit_pois <- tsglm(campy, model=list(past_obs=1, past_mean=13),
-                  xreg=interventions, dist="poisson")
-campyfit_nbin <- tsglm(campy, model=list(past_obs=1, past_mean=13),
-                  xreg=interventions, dist="nbinom")
+interventions <- interv_covariate(n = length(campy), tau = c(84, 100),
+                  delta = c(1, 0))
+campyfit_pois <- tsglm(campy, model = list(past_obs = 1, past_mean = 13),
+                  xreg = interventions, distr = "poisson")
+campyfit_nbin <- tsglm(campy, model = list(past_obs = 1, past_mean = 13),
+                  xreg = interventions, distr = "nbinom")
 
 
 ###################################################
 ### code chunk number 4: campy3a
 ###################################################
-par(mfrow=c(2,2), mar=c(4,4,3,1), mgp=c(2.5,1,0))
-acf(residuals(campyfit_pois), main="ACF of response residuals")
-marcal(campyfit_pois, ylim=c(-0.03, 0.03), main="Marginal calibration")
-  lines(marcal(campyfit_nbin, plot=FALSE), lty="dashed")
-  legend("bottomright", legend=c("Pois", "NegBin"), lwd=1,
+par(mfrow = c(2, 2), mar=c(3, 4, 2, 0.5), mgp=c(1.8, 0.6, 0))
+acf(residuals(campyfit_pois), main="", xlab="Lag (in years)")
+title(main = "ACF of response residuals")
+marcal(campyfit_pois, ylim = c(-0.03, 0.03), main = "Marginal calibration")
+  lines(marcal(campyfit_nbin, plot = FALSE), lty = "dashed")
+  legend("bottomright", legend = c("Pois", "NegBin"), lwd=1,
          lty=c("solid", "dashed"))
-pit(campyfit_pois, ylim=c(0, 1.5), main="PIT Poisson")
-pit(campyfit_nbin, ylim=c(0, 1.5), main="PIT Negative Binomial")
+pit(campyfit_pois, ylim = c(0, 1.5), main = "PIT Poisson")
+pit(campyfit_nbin, ylim = c(0, 1.5), main = "PIT Negative Binomial")
 
 
 ###################################################
 ### code chunk number 5: campy3b (eval = FALSE)
 ###################################################
-## acf(residuals(campyfit_pois), main="ACF of response residuals")
-## marcal(campyfit_pois, ylim=c(-0.03, 0.03), main="Marginal calibration")
-##   lines(marcal(campyfit_nbin, plot=FALSE), lty="dashed")
-##   legend("bottomright", legend=c("Pois", "NegBin"), lwd=1,
-##          lty=c("solid", "dashed"))
-## pit(campyfit_pois, ylim=c(0, 1.5), main="PIT Poisson")
-## pit(campyfit_nbin, ylim=c(0, 1.5), main="PIT Negative Binomial")
+## acf(residuals(campyfit_pois), main = "ACF of response residuals")
+## marcal(campyfit_pois, ylim = c(-0.03, 0.03), main = "Marginal calibration")
+##   lines(marcal(campyfit_nbin, plot = FALSE), lty = "dashed")
+##   legend("bottomright", legend = c("Pois", "NegBin"), lwd = 1,
+##          lty = c("solid", "dashed"))
+## pit(campyfit_pois, ylim = c(0, 1.5), main = "PIT Poisson")
+## pit(campyfit_nbin, ylim = c(0, 1.5), main = "PIT Negative Binomial")
 
 
 ###################################################
 ### code chunk number 6: campy4
 ###################################################
-rbind(Poisson=scoring(campyfit_pois), NegBin=scoring(campyfit_nbin))
+rbind(Poisson = scoring(campyfit_pois), NegBin = scoring(campyfit_nbin))
 
 
 ###################################################
@@ -72,7 +73,7 @@ load("campy.RData")
 ###################################################
 ### code chunk number 9: campy6b (eval = FALSE)
 ###################################################
-## se(campyfit_nbin, B=500)$se
+## se(campyfit_nbin, B = 500)$se
 
 
 ###################################################
@@ -85,23 +86,23 @@ warningse[length(warningse)]
 ###################################################
 ### code chunk number 11: seatbelts1
 ###################################################
-par(mar=c(4,4,1,1), mgp=c(2.5,1,0))
-plot(Seatbelts[, "VanKilled"], ylab="Number of casualties", type="o", xaxt="n")
-axis(side=1, at=1969:1985)
-abline(v=1983, col="darkgrey")
+par(mar=c(3, 3, 0.5, 0.5), mgp=c(1.8, 0.6, 0))
+plot(Seatbelts[, "VanKilled"], ylab = "Number of casualties", type = "o", xaxt = "n", ylim = c(0, 18))
+axis(side = 1, at = 1969:1985)
+abline(v = 1983, col = "darkgrey", lwd=2)
 
 
 ###################################################
 ### code chunk number 12: seatbelts2
 ###################################################
 timeseries <- Seatbelts[, "VanKilled"]
-regressors <- cbind(PetrolPrice=Seatbelts[, c("PetrolPrice")],
-                    linearTrend=seq(along=timeseries)/12)
-timeseries_until1981 <- window(timeseries, end=1981+11/12)
-regressors_until1981 <- window(regressors, end=1981+11/12)
-seatbeltsfit <- tsglm(ts=timeseries_until1981,
-  model=list(past_obs=c(1, 12)), link="log", distr="pois",
-  xreg=regressors_until1981)
+regressors <- cbind(PetrolPrice = Seatbelts[, c("PetrolPrice")],
+                    linearTrend = seq(along = timeseries)/12)
+timeseries_until1981 <- window(timeseries, end = 1981 + 11/12)
+regressors_until1981 <- window(regressors, end = 1981 + 11/12)
+seatbeltsfit <- tsglm(timeseries_until1981,
+  model = list(past_obs = c(1, 12)), link = "log", distr = "poisson",
+  xreg = regressors_until1981)
 
 
 ###################################################
@@ -113,7 +114,7 @@ load("seatbelts.RData")
 ###################################################
 ### code chunk number 14: seatbelts3b (eval = FALSE)
 ###################################################
-## summary(seatbeltsfit, B=500)
+## summary(seatbeltsfit, B = 500)
 
 
 ###################################################
@@ -124,58 +125,239 @@ seatbeltssummary
 
 
 ###################################################
-### code chunk number 16: seatbelts4
+### code chunk number 16: seatbelts4a
 ###################################################
-timeseries_1982 <- window(timeseries, start=1982, end=1982+11/12)
-regressors_1982 <- window(regressors, start=1982, end=1982+11/12) 
-predict(seatbeltsfit, n.ahead=12, level=1-0.1/12, B=2000,
-        newxreg=regressors_1982)$fit
+opts <- options(digits=3)
 
 
 ###################################################
-### code chunk number 17: seatbelts5
+### code chunk number 17: seatbelts4b
 ###################################################
-par(mar=c(4,4,1,1), mgp=c(2.5,1,0))
-predictions_1982 <- predict(seatbeltsfit, n.ahead=12,
-                            level=1-0.05/12, B=2000,
-                            newxreg=regressors_1982)
-plot(window(timeseries, end=1982.917), type="o",
-     xlim=c(1978.7, 1982.9), ylim=c(0, 20), ylab="Number of casualities")
-lines(fitted(seatbeltsfit), col="blue", lty="dashed", lwd=2)
-arrows(x0=time(predictions_1982$interval_shortest), y0=predictions_1982$interval_shortest[, "lower"], y1=predictions_1982$interval_shortest[, "upper"], angle=90, code=3, length=0.04, col="darkgrey", lwd=2)
-points(timeseries_1982, pch=16, type="o") 
-lines(x=c(1981.917, time(predictions_1982$fit)), c(fitted(seatbeltsfit)[156], predictions_1982$fit), col="red", lty="solid", lwd=2)
+timeseries_1982 <- window(timeseries, start = 1982, end = 1982 + 11/12)
+regressors_1982 <- window(regressors, start = 1982, end = 1982 + 11/12) 
+predict(seatbeltsfit, n.ahead = 12, level = 0.9, global = TRUE,
+        B = 2000, newxreg = regressors_1982)$pred
 
 
 ###################################################
-### code chunk number 18: seatbelts6a
+### code chunk number 18: seatbelts4c
 ###################################################
-seatbeltsfit_alldata <- tsglm(ts=timeseries, link="log",
-                              model=list(past_obs=c(1, 12)),
-                              xreg=regressors, distr="pois")
+options(opts)
 
 
 ###################################################
-### code chunk number 19: seatbelts6b
+### code chunk number 19: seatbelts5
 ###################################################
-seatbelts_test <- interv_test(seatbeltsfit_alldata, tau=170,
-                              delta=1, est_interv=TRUE)
+par(mar=c(3, 3, 0.5, 0.5), mgp=c(1.8, 0.6, 0))
+predictions_1982 <- predict(seatbeltsfit, n.ahead = 12,
+                            level = 0.9, global = TRUE,
+                            B = 2000, newxreg = regressors_1982)
+plot(window(timeseries, end = 1982.917), type = "o",
+     xlim = c(1978.7, 1982.9), ylim = c(0, 20), ylab = "Number of casualities")
+lines(fitted(seatbeltsfit), col = "blue", lty = "dashed", lwd = 2)
+arrows(x0 = time(predictions_1982$interval), y0 = predictions_1982$interval[, "lower"], y1 = predictions_1982$interval[, "upper"], angle = 90, code = 3, length = 0.04, col = "darkgrey", lwd = 2)
+points(timeseries_1982, pch = 16, type = "o") 
+lines(x = c(1981.917, time(predictions_1982$pred)), c(fitted(seatbeltsfit)[156], predictions_1982$pred), col = "red", lty = "solid", lwd = 2)
 
 
 ###################################################
-### code chunk number 20: seatbelts6c (eval = FALSE)
+### code chunk number 20: seatbelts6a
 ###################################################
-## interv_test(seatbeltsfit_alldata, tau=170, delta=1, est_interv=TRUE)
+seatbeltsfit_alldata <- tsglm(timeseries, link = "log",
+                              model = list(past_obs = c(1, 12)),
+                              xreg = regressors, distr = "poisson")
 
 
 ###################################################
-### code chunk number 21: seatbelts6d
+### code chunk number 21: seatbelts6b
+###################################################
+seatbelts_test <- interv_test(seatbeltsfit_alldata, tau = 170,
+                              delta = 1, est_interv = TRUE)
+
+
+###################################################
+### code chunk number 22: seatbelts6c (eval = FALSE)
+###################################################
+## interv_test(seatbeltsfit_alldata, tau = 170, delta = 1, est_interv = TRUE)
+
+
+###################################################
+### code chunk number 23: seatbelts6d
 ###################################################
 seatbelts_test
 
 
 ###################################################
-### code chunk number 22: recursioninit
+### code chunk number 24: tsglm-comparison
+###################################################
+campyfit_tsglm <- tsglm(campy, model = list(past_obs = 1, past_mean = 13),
+                        distr = "nbinom", link = "identity")
+#model like in the Section 'Usage' but without considering the intervention effects
+
+
+###################################################
+### code chunk number 25: glm-function
+###################################################
+campydata <- data.frame(ts = campy[-1], lag1 = campy[-length(campy)])
+coef(glm(ts ~ lag1, family = poisson(link = "identity"), data = campydata))
+coef(tsglm(campy, model = list(past_obs = 1), link = "identity")) 
+
+
+###################################################
+### code chunk number 26: gamlss-package
+###################################################
+library("gamlss")
+gamlss(ts ~ lag1, sigma.formula = ~ log(lag1+1), data = campydata,
+       family = NBI(mu.link = "identity", sigma.link = "log"))[c(25, 43)]
+
+
+###################################################
+### code chunk number 27: VGAM-package
+###################################################
+library("VGAM")
+coef(vglm(ts ~ lag1, family = poissonff(link = "identitylink"),
+          data = campydata))
+
+
+###################################################
+### code chunk number 28: acp-package
+###################################################
+library("acp")
+coef(acp(campy ~ -1, p = 1, q = 1))
+coef(tsglm(campy, model = list(past_obs = 1, past_mean = 1)))
+
+
+###################################################
+### code chunk number 29: glarma-package1
+###################################################
+library("glarma")
+glarmaModelEstimates(glarma(campy, phiLags = 1:3, thetaLags = 13,
+    residuals = "Pearson", X = cbind(intercept=rep(1, length(campy))),
+    type = "NegBin"))[c("Estimate", "Std.Error")]
+
+
+###################################################
+### code chunk number 30: glarma-package2
+###################################################
+campyfit_glarma <- glarma(campy, phiLags = 1:3, thetaLags = 13, 
+                          X = cbind(intercept=rep(1, length(campy))),
+                          type = "NegBin", residuals = "Pearson")
+
+
+###################################################
+### code chunk number 31: gamlss.util-package
+###################################################
+library("gamlss.util")
+coef(garmaFit(campy ~ 1, order = c(1, 1), family = NBI(mu.link = "log")))
+
+
+###################################################
+### code chunk number 32: VGAM-package2
+###################################################
+coef(vglm(campy ~ 1, family = garma(link="loge", p.ar.lag = 1, q.ma.lag = 0,
+                                    coefstart = c(0.1, 0.1))))
+
+
+###################################################
+### code chunk number 33: INLA-package1a (eval = FALSE)
+###################################################
+## library("INLA")
+## campyfit_INLA <- inla(ts ~ f(time, model = "rw1", cyclic = FALSE),
+##                 data = data.frame(time = seq(along = campy), ts = campy),
+##                 family = "nbinomial", E = mean(campy),
+##                 control.predictor = list(compute = TRUE, link = 1),
+##                 control.compute = list(cpo = FALSE, config = TRUE),
+##                 control.inla = list(int.strategy = "grid", dz = 1,
+##                                     diff.logdens = 10))
+## posterior <- inla.posterior.sample(1000, campyfit_INLA)
+## rowMeans(sapply(posterior, function(x) (unname(x$hyperpar))))
+
+
+###################################################
+### code chunk number 34: INLA-package1b
+###################################################
+#campyest_INLA <- rowMeans(sapply(posterior, function(x) (unname(x$hyperpar))))
+#mu <- rowMeans(sapply(posterior, function(x) exp(unname(x$latent[seq(along=campy), 1]))))
+#campyfitted_INLA <- mu*mean(campy)
+#save(campyest_INLA, campyfitted_INLA, file="INLA.RData")
+load("INLA.RData")
+
+
+###################################################
+### code chunk number 35: INLA-package1c
+###################################################
+campyest_INLA
+
+
+###################################################
+### code chunk number 36: KFAS-package
+###################################################
+library("KFAS")
+model <- SSModel(campy ~ SSMcustom(Z = 1, T = 1, R = 1, Q = 0,
+                                   a1 = NA, P1 = NA) - 1, 
+                 distribution = "negative binomial", u = NA)
+updatefn <- function(pars, model, ...){
+  model$a1[1, 1] <- pars[1]
+  model$u[, 1] <- exp(pars[2])
+  model$P1[1, 1] <- exp(pars[3])
+  model$Q[1,1,1] <- exp(pars[4])
+  return(model)
+}
+campyfit_KFAS <- fitSSM(model = model, inits = c(mean(campy), 0, 0, 0),
+                updatefn = updatefn)
+exp(campyfit_KFAS$optim.out$par)
+
+
+###################################################
+### code chunk number 37: comparison-acf
+###################################################
+par(mar=c(3, 3, 0.5, 0.5), mgp=c(1.8, 0.6, 0))
+layout(matrix(1:4, ncol=2))
+acf(campy - fitted(campyfit_tsglm), main="")
+legend("top", bty="n", legend="", title="tsglm", cex=1.3) 
+acf(campy - fitted(campyfit_glarma), main="")
+legend("top", bty="n", legend="", title="glarma", cex=1.3) 
+acf(campy - campyfitted_INLA, main="")
+legend("top", bty="n", legend="", title="INLA", cex=1.3)
+acf(campy - predict(campyfit_KFAS$model), main="")
+legend("top", bty="n", legend="", title="KFAS", cex=1.3)
+
+
+###################################################
+### code chunk number 38: comparison-fit
+###################################################
+par(mar=c(3, 3, 0.5, 0.5), mgp=c(1.8, 0.6, 0))
+plot(campy, type="p", xlim=c(1996, 2000.6), ylab="Number of cases", main="")
+lines(fitted(campyfit_tsglm), lwd=2, lty="solid")
+lines(as.numeric(time(campy)), fitted(campyfit_glarma), lwd=2, lty="dashed", col="darkorange")
+lines(as.numeric(time(campy)), campyfitted_INLA, lwd=2, lty="longdash", col="blue")
+lines(as.numeric(time(campy)), predict(campyfit_KFAS$model), lwd=2, lty="dotdash", col="red")
+legend("topright", legend=c("tsglm", "glarma", "INLA", "KFAS"), lwd=2, lty=c("solid", "dashed", "longdash", "dotdash"), col=c("black", "darkorange", "blue", "red"), seg.len=5)
+
+
+###################################################
+### code chunk number 39: gcmr-package-pre
+###################################################
+width <- getOption("width")
+options(width=50)
+
+
+###################################################
+### code chunk number 40: gcmr-package
+###################################################
+library("gcmr")
+gcmr(ts ~ 1, marginal = negbin.marg(link = "identity"),
+     cormat = arma.cormat(p=1, q=1), data = data.frame(ts = campy))
+
+
+###################################################
+### code chunk number 41: gcmr-package-post
+###################################################
+options(width=width)
+
+
+###################################################
+### code chunk number 42: recursioninit
 ###################################################
 set.seed(1246)
 timser <- tsglm.sim(n=1000, param=list(intercept=0.5, past_obs=0.77, past_mean=0.22), model=list(past_obs=1, past_mean=1), link="identity")$ts
@@ -194,14 +376,14 @@ comparison <- rbind(
   c(fit_firstobs.drop$coefficients, fit_firstobs.drop$logLik)
 )
 colnames(comparison) <- c("$\\widehat{\\beta}_0$", "$\\widehat{\\beta}_1$", "$\\widehat{\\alpha}_1$", "$\\ell(\\widehat{\\boldsymbol{\\theta}})$")
-rownames(comparison) <- c("\\texttt{init.method=\"marginal\", init.drop=FALSE}", "\\texttt{init.method=\"marginal\", init.drop=TRUE}", "\\texttt{init.method=\"iid\", \\hspace{2em} init.drop=FALSE}", "\\texttt{init.method=\"iid\", \\hspace{2em} init.drop=TRUE}", "\\texttt{init.method=\"firstobs\", init.drop=FALSE}", "\\texttt{init.method=\"firstobs\", init.drop=TRUE}")
+rownames(comparison) <- c("\\code{init.method = \"marginal\", init.drop = FALSE}", "\\code{init.method = \"marginal\", init.drop = TRUE}", "\\code{init.method = \"iid\", \\hspace{2em} init.drop = FALSE}", "\\code{init.method = \"iid\", \\hspace{2em} init.drop = TRUE}", "\\code{init.method = \"firstobs\", init.drop = FALSE}", "\\code{init.method = \"firstobs\", init.drop = TRUE}")
 
 library("xtable")
-print(xtable(comparison, caption="Estimated parameters and log-likelihood of a time series of length 1000 simulated from model \\eqref{eq:linear} for different initialization strategies. The true parameters are $\\beta_0=0.5$, $\\beta_1=0.77$ and $\\alpha_1=0.22$.", label="tab:recursioninit", align="lcccc", digits=c(0,3,3,3,1)), table.placement="tbp", caption.placement="bottom", booktabs=TRUE, comment=FALSE, sanitize.text.function=function(x){x})
+print(xtable(comparison, caption="Estimated parameters and log-likelihood of a time series of length 1000 simulated from model \\eqref{eq:linear} for different initialization strategies. The true parameters are $\\beta_0=0.5$, $\\beta_1=0.77$ and $\\alpha_1=0.22$. Likelihood values are included for completeness of the presentation. There are not comparable as they are based on a different number of observations.", label="tab:recursioninit", align="lcccc", digits=c(0,3,3,3,1)), table.placement="tbp", caption.placement="bottom", booktabs=TRUE, comment=FALSE, sanitize.text.function=function(x){x})
 
 
 ###################################################
-### code chunk number 23: covariates_load
+### code chunk number 43: covariates_load
 ###################################################
 load("covariates.RData")
 estimates_list_id <- list(covariate_n100_id, covariate_n500_id, covariate_n1000_id, covariate_n2000_id)
@@ -209,16 +391,15 @@ estimates_list_log <- list(covariate_n100_log, covariate_n500_log, covariate_n10
 
 
 ###################################################
-### code chunk number 24: covariates_scatterplots
+### code chunk number 44: covariates_scatterplots
 ###################################################
 covariate_scatterplots <- function(x, main="", truevalue, show=1:12){
   #will only show the first eight types of covariates in vector 'show'
-  par(mfrow=c(4,2), mar=c(0.25,0.25,0,0), las=1, mgp=c(1.5,0.6,0), oma=c(2.5,2.5,2.5,1))
-  #layout(matrix(c(1,3,5,7,2,4,6,8), ncol=2))
+  par(mfrow=c(4,2), mar=c(0.25,0.25,0,0), mgp=c(1.8,0.6,0), oma=c(2.5,2.5,2.5,1))
   estimates_cov <- sapply(x$estimates[show], function(x) x[4, ])
   estimates_dep <- sapply(x$estimates[show], function(x) x[2, ]) + sapply(x$estimates[show], function(x) x[3, ])
   minmax_cov <- c(min(apply(estimates_cov, 2, quantile, probs=0.0055, na.rm=TRUE)), max(apply(estimates_cov, 2, quantile, probs=0.9994, na.rm=TRUE)))
-  minmax_cov[2] <- minmax_cov[2]+0.2*(diff(minmax_cov)) #enlarge range to have space for the plot title placed within the plot region
+  minmax_cov[2] <- minmax_cov[2]+0.15*(diff(minmax_cov)) #enlarge range to have space for the plot title placed within the plot region
   minmax_dep <- c(min(apply(estimates_dep, 2, quantile, probs=0.0055, na.rm=TRUE)), max(apply(estimates_dep, 2, quantile, probs=0.9994, na.rm=TRUE)))
 covariate_labels <- c("Linear", "Quadratic", "Sine", "Sine (fixed width)", "Spiky outlier", "Transient shift", "Level shift", "GARCH(1,1)", "Poisson", "Exponential", "Normal", "Chi^2")
   for(j in seq(along=show)){
@@ -246,7 +427,7 @@ invisible(dev.off())
 
 
 ###################################################
-### code chunk number 25: covariates_boxplots
+### code chunk number 45: covariates_boxplots
 ###################################################
 covariate_boxplots <- function(estimates_list, index, truevalue, main="", label="", show=1:12){
   number_covariates <- length(show)
@@ -292,12 +473,11 @@ invisible(dev.off())
 
 
 ###################################################
-### code chunk number 26: covariates_qqplots
+### code chunk number 46: covariates_qqplots
 ###################################################
 covariate_qqplots <- function(x, main="", truevalue, show=1:12){
   #will only show the first eight types of covariates in vector 'show'
-  par(mfrow=c(4,2), mar=c(0.25,0.25,0,0), las=1, mgp=c(1.5,0.6,0), oma=c(2.5,2.5,2.5,1))
-  #layout(matrix(c(1,3,5,7,2,4,6,8), ncol=2))
+  par(mfrow=c(4,2), mar=c(0.25,0.25,0,0), mgp=c(1.8,0.6,0), oma=c(2.5,2.5,2.5,1))
   estimates <- sapply(x$estimates[show], function(x) x[4, ])
   minmax <- c(min(apply(estimates, 2, quantile, probs=0.0055, na.rm=TRUE)), max(apply(estimates, 2, quantile, probs=0.9994, na.rm=TRUE)))
 covariate_labels <- c("Linear", "Quadratic", "Sine", "Sine (fixed width)", "Spiky outlier", "Transient shift", "Level shift", "GARCH(1,1)", "Poisson", "Exponential", "Normal", "Chi^2")
@@ -326,7 +506,7 @@ invisible(dev.off())
 
 
 ###################################################
-### code chunk number 27: distrcoef_load
+### code chunk number 47: distrcoef_load
 ###################################################
 load("distrcoef_size1.RData")
 estimates_distrcoef_size1_id <- sapply(list(distrcoef_n100_size1_id, distrcoef_n500_size1_id, distrcoef_n1000_size1_id, distrcoef_n2000_size1_id), function(x) x$estimates[4, ])
@@ -336,7 +516,7 @@ load("distrcoef_n200.RData")
 
 
 ###################################################
-### code chunk number 28: distrcoef_summary
+### code chunk number 48: distrcoef_summary
 ###################################################
 distrcoef_nu <- function(estimates) c(mean=mean(estimates, na.rm=TRUE), median=median(estimates, na.rm=TRUE), sd=sd(estimates, na.rm=TRUE), mad=mad(estimates, na.rm=TRUE), propNA=mean(is.na(estimates))*100)
 # distrcoef_id_summary <- rbind(
@@ -361,7 +541,7 @@ print(xtable(distrcoef_log_summary, caption="Summary statistics for the estimate
 
 
 ###################################################
-### code chunk number 29: distrcoef_boxplots
+### code chunk number 49: distrcoef_boxplots
 ###################################################
 ##RMSE:
 #apply(estimates_distrcoef_size1_id, 2, function(x) sqrt(mean((x-1)^2)))
